/***********************************************************************************************************************
 *
 * blueMarine Metadata - open source media workflow
 * Copyright (C) 2007-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluemarine.tidalwave.it
 * SCM: https://kenai.com/hg/bluemarine~metadata-src
 *
 **********************************************************************************************************************/
package it.tidalwave.metadata.exif.persistence;

import it.tidalwave.metadata.persistence.spi.UnknownPropertyException;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import static org.junit.Assert.*;
import it.tidalwave.image.metadata.EXIF;
import it.tidalwave.image.metadata.EXIFDirectoryGenerated.Contrast;

/*******************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 ******************************************************************************/
public class EXIFBeanAccessorTest 
  {
    private EXIFBeanAccessor beanAccessor;
    private EXIF EXIF;
    
    @Before
    public void setupFixture()
      {
        beanAccessor = new EXIFBeanAccessor();
        EXIF = new EXIF();
        EXIF.setArtist("Fabrizio Giudici");
        EXIF.setContrast(Contrast.SOFT);
      }
    
    @After
    public void tearDownFixture()
      {
        beanAccessor = null;
        EXIF = null;
      }
    
    @Test
    public void testGetPropertyType() 
      throws UnknownPropertyException
      {
        assertEquals(String.class, beanAccessor.getDefaultPropertyType("#" + EXIF.ARTIST));
        assertEquals(Integer.class, beanAccessor.getDefaultPropertyType("#" + EXIF.CONTRAST)); // enum
      }
    
    @Test
    public void testConvert()
      throws UnknownPropertyException
      {
        assertEquals("Fabrizio Giudici", beanAccessor.convertValueToPersistence("artist", "Fabrizio Giudici"));
        assertEquals(1, beanAccessor.convertValueToPersistence("contrast", Contrast.SOFT));
//        assertEquals(1, beanAccessor.convert("contrast", Contrast.SOFT));
      }
    
    @Test
    public void testConvertReverse()
      throws UnknownPropertyException
      {
        assertEquals("Fabrizio Giudici", beanAccessor.convertValueFromPersistence("artist", "Fabrizio Giudici"));
        assertEquals(Contrast.SOFT, beanAccessor.convertValueFromPersistence("contrast", 1));
//        assertEquals(Contrast.SOFT, beanAccessor.convertReverse("contrast", 1));
      }
    
    @Test
    public void testGetProperty()
      throws UnknownPropertyException
      {
        assertEquals("Fabrizio Giudici", beanAccessor.getProperty("#" + EXIF.ARTIST, EXIF));
        assertEquals(1, beanAccessor.getProperty("#" + EXIF.CONTRAST, EXIF));
      }
    
    @Test
    public void testSetProperty()
      throws UnknownPropertyException
      {
        beanAccessor.setProperty(EXIF, "#" + EXIF.ARTIST, "John Doe");
        beanAccessor.setProperty(EXIF, "#" + EXIF.CONTRAST, 2);
        assertEquals("John Doe", EXIF.getArtist());
        assertEquals(Contrast.HARD, EXIF.getContrast());
      }
  }